@@ -5,11 +5,13 @@
 #' @seealso
 #' \code{\link{beta2tau}}
 #' @export
-theta2tau <- function(theta = list(beta = c(0, 1)), distname) {
+theta2tau <- function(theta = list(beta = c(0, 1)), distname, 
+                      use.mean.variance = TRUE) {
   
   check_distname(distname)
   theta <- complete_theta(theta)
-  tau <- beta2tau(beta = theta$beta, distname = distname)
+  tau <- beta2tau(beta = theta$beta, distname = distname,
+                  use.mean.variance = use.mean.variance)
 
   if (length(theta$alpha) == 1) {
     tau["alpha"] <- theta$alpha
@@ -17,6 +19,8 @@ theta2tau <- function(theta = list(beta = c(0, 1)), distname) {
   } else if (length(theta$alpha) == 2) {
     tau[c("alpha_l", "alpha_r")] <- theta$alpha    
     tau <- tau[setdiff(names(tau), c("alpha"))] 
+  } else if (length(theta$alpha) > 2) {
+    stop("alpha can't have more than 2 entries.")
   }
   
   if (length(theta$gamma) == 1) {
